open Lexing
open Ast
open TpParse

let output token =
    match token with
      STRING str -> "Constante chaine: " ^ str
    | CSTE v -> "Constante entiere: " ^ (string_of_int v)
    | IDC id -> "Id classe: " ^ id
    | ID id  -> "Idend: " ^ id
    | RELOP op -> "operateur " ^ Misc.string_of_relop op
    | PLUS     -> "operateur +"
    | MINUS    -> "operateur -"
    | TIMES    -> "operateur *"
    | DIV      -> "operateur /"
    | DOT
    | CONCAT
    | COMMA
    | COLON
    | SEMICOLON
    | LPAREN
    | LCBRAC
    | RPAREN
    | RCBRAC   -> "symbole basique"
    | ASSIGN   -> "affectation"
    | CLASS    -> "mot-clef CLASS"
    | EXTENDS  -> "mot-clef EXTENDS"
    | IS       -> "mot-clef IS"
    | VAR      -> "mot-clef: VAR"
    | STATIC   -> "mot-clef: STATIC"
    | DEF      -> "mot-clef: DEF"
    | OVERRIDE -> "mot-clef: OVERRIDE"
    | NEW      -> "mot-clef: NEW"
    | AS       ->  "mot-clef: AS"
    | IF       -> "mot-clef: IF"
    | THEN     -> "mot-clef: THEN"
    | ELSE     -> "mot-clef: ELSE"
    | RETURN   -> "mot-clef: RETURN"
    | EOF       (* caught before being sent to this function *)
    | UMINUS   -> failwith "unexpected token to print"



let () =
  let lexbuf, withFile =
    if Array.length Sys.argv = 1 then  Lexing.from_channel stdin, None
    else let file = open_in Sys.argv.(1) in Lexing.from_channel file, Some file
  in
  let rec process () =
    match TpLex.token lexbuf with
      EOF -> begin match withFile with Some f -> close_in f | _ -> () end
    | tok -> print_endline (output tok); process ()
  in
  process ();
;;
